# Example Poll 2: multi-answer and rank questions.
Results of an opinion poll made in Israel circa 5/2021, aimed to check the potential outcome of switching to approval voting.

The poll is more complex, and contains single-answer questions, multi-answer questions and rank questions.

See [analyze.py](analyze.py) for usage example.
